==> haskell-pandoc-crossref-0.2.3.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.3.0
id: pandoc-crossref-0.2.3.0-GdpsKorbh71A4foKf6aji1
key: pandoc-crossref-0.2.3.0-GdpsKorbh71A4foKf6aji1
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 9a246e96117f4fb44b0a3a2192ac4976
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.3.0
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.3.0-GdpsKorbh71A4foKf6aji1
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-1.17.2-HlbqfOu3rUp3lWNwhCA7m1
    pandoc-types-1.16.1.1-JObJUsTHa9C6nuwoNLaRnR
    roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    yaml-0.8.18.5-4esdxobKVop1crLfxryJbi
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-crossref-0.2.3.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.3.0
id: pandoc-crossref-0.2.3.0-350D0cRki5RGwRnGcRREf
key: pandoc-crossref-0.2.3.0-350D0cRki5RGwRnGcRREf
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: b0fb80f9ee68e7f70be8f8183eb875cf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.3.0
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.3.0-350D0cRki5RGwRnGcRREf
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-1.17.2-8Ioqz6XlvjgAGmaYRwdAgd
    pandoc-types-1.16.1.1-DxO5HnQkuvb5R4LlZL94h3
    roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    yaml-0.8.18.6-6QtJfLcwYFW9AqXH8y2yNn
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
